@@ -586,12 +586,16 @@ class Witter():
             while (item != None) and (counter < 20):
                 f5.write("senderName" + str(counter) + " = " + store.get_value(item,0)+"\n")
                 f5.write("senderId" + str(counter) + " = " +store.get_value(item,1)+"\n")
-                f5.write("tweet" + str(counter) + " = " + store.get_value(item, 2)+"\n")
+                tweet = store.get_value(item,2)
+		tweet = tweet.replace("\n","&CR;")
+		f5.write("tweet" + str(counter) + " = " +tweet+"\n")
                 #3 is unused now, used to be tweet colour
                 f5.write("tweetId" + str(counter) + " = " +str(store.get_value(item,4))+"\n")
                 f5.write("type" + str(counter)+" = " + str(store.get_value(item,5))+"\n")
                 f5.write("createdAt" + str(counter) + " = " +store.get_value(item,6)+"\n")
-                f5.write("replyTo" + str(counter) + " = " +store.get_value(item,7)+"\n")
+                reply = store.get_value(item,7)
+		reply = reply.replace("\n","&CR;")
+		f5.write("replyTo" + str(counter) + " = " +reply+"\n")
                 f5.write("source" + str(counter) + " = " +store.get_value(item,8)+"\n")
                 #9 is avatar pic
                 formattedTweet = store.get_value(item,10)
@@ -615,11 +619,13 @@ class Witter():
                 senderName = config.get("tweets", "senderName" + str(counter));
                 senderId = config.get("tweets", "senderId" + str(counter));
                 tweet = config.get("tweets", "tweet" + str(counter));
-                tweetId = config.get("tweets", "tweetId" + str(counter));
+                tweet = tweet.replace("&CR;","\n")
+		tweetId = config.get("tweets", "tweetId" + str(counter));
                 tweet_long_id = float(tweetId)
                 createdAt = config.get("tweets", "createdAt" + str(counter));
                 replyTo = config.get("tweets", "replyTo" + str(counter));
-                type = config.get("tweets", "type" + str(counter));
+                replyTo = replyTo.replace("&CR;","\n")
+		type = config.get("tweets", "type" + str(counter));
                 source = config.get("tweets", "source" + str(counter));
                 formattedTweet = config.get("tweets", "formattedTweet" + str(counter));
                 formattedTweet = formattedTweet.replace("&CR;", "\n")
